# pulser-core

[Pulser](https://pypi.org/project/pulser/) is a framework for composing, simulating and executing **pulse** sequences for neutral-atom quantum devices.

This is the `pulser-core` package, which provides the core functionalities needed to create sequences
with `pulser`.

## Installation

The standard Pulser installation,

```bash
pip install pulser
```

will automatically install `pulser-core`, along with the extension packages.
If you wish to install `pulser-core` on its own, you can instead run

```bash
pip install pulser-core
```
